package no.rune.mavenplugins.dla;

import java.io.File;

import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.logging.Log;



/**
 * The base class for all MOJOs of the <tt>dla-maven-plugin</tt>.
 * 
 * @author Rune Flobakk
 * @version 1.0.0
 */
public abstract class AbstractDlaPluginMojo extends AbstractMojo
{
    
    /**
     * The directory containing XML sources specifying which DLAs
     * to run on the project.
     * @parameter expression="${basedir}/src/test/dla"
     * @required
     */
    protected File sourceDirectory;
    
    

    /**
     * The DLA source file name
     * @parameter expression="dla.xml"
     * @required
     */
    protected String dlaFile;

    
    
    /**
     * 
     * @parameter expression="${project.build.sourceDirectory}"
     * @required
     * @readonly
     */
    protected File javaSourceDirectory;

    
    /**
     * Default directory for generated AspectJ sources.
     * 
     * @parameter expression="${project.build.directory}/generated-sources/dla"
     * @required
     * @readonly
     */
    private File defaultAspectDirectory;
    
    
    /**
     * The directory to place generated AspectJ sources if these are to be
     * included with manually written aspects.
     * 
     * @parameter expression="${basedir}/src/main/aspect"
     */
    private File aspectDirectory;
    
    
    /**
     * @parameter default-value="false"
     * @required
     */
    protected boolean enableAspectJ;
    
    
    
    /**
     * The Maven log object.
     */
    protected Log log;
    
    

    
    /**
     * This method will make sure that a directory exists.
     * <p>
     * <tt>&lt;offTopic&gt;</tt><br/>
     * This method should be a great candidate to implement the dreaded
     * <a href="http://worsethanfailure.com/Articles/What_Is_Truth_0x3f_.aspx">
     *    Tri-State Boolean </a> ;-)<br/>
     * <tt>&lt;/offTopic&gt;</tt>
     * </p>
     * @param files One or more directories.
     * @return <code>true</code> if the directory exists or was created, 
     *         <code>false</code> if it could not be created if for instance
     *         the file parameter specifies a file, not a directory.
     */
    protected boolean acquireDirectory( File ... files )
    {
        log = getLog();
        
        for( File file : files )
        {
            if( file.exists() && file.isDirectory() )
            {
                log.debug( file + " already exists." );
            }
            else if( ! file.exists() && file.mkdirs() )
            {
                log.debug( file + " created." );
            }
            else
            {
                log.error( "Cannot acquire directory " + file );
                return false;
            }
        }
        return true;
    }
    

    /**
     * Gets the directory from where source aspects are located.
     * 
     * @return The directory
     */
    protected File getAspectDirectory()
    {
        return ( enableAspectJ )? aspectDirectory : defaultAspectDirectory;
    }

}
