package no.rune.mavenplugins.dla;




import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;

import java.io.InputStream;

import no.rune.mavenplugins.dla.processor.XslTransformer;

import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;


/**
 * This will generate AspectJ source files.
 * 
 * @author Rune Flobakk
 * @version 1.0.0
 * @goal generate-aspects
 * @phase generate-test-resources
 */
public class AspectGeneratorMojo extends AbstractDlaPluginMojo
{
    
    /**
     * Location of the XSLT stylesheet to use for AspectJ source generation.
     */
    private static final String DLA_STYLESHEET = "xslt/aspectj.xsl";
    
    
    
    
    
    /**
     * @see org.apache.maven.plugin.Mojo#execute()
     */
    public void execute() throws MojoExecutionException, MojoFailureException
    {
        log = getLog();
        
        //verify presence of dla.xml file
        File dlaSource = new File( sourceDirectory, dlaFile );
        if( ! dlaSource.exists() )
            throw new MojoExecutionException( "DLA definition file (" +
                dlaSource +") not found!" );

        
        //verify presence of the XSLT stylesheet file bundled with the plugin
        InputStream stylesheet =
            this.getClass().getResourceAsStream( "/" + DLA_STYLESHEET );
        if( stylesheet == null )
            throw new MojoExecutionException( "DLA transformation file cannot " +
                    "be found.");
        
        

        if( ! acquireDirectory( getAspectDirectory() ) )
        {
            throw new MojoExecutionException( 
                "Cannot write aspects to directory " + getAspectDirectory() );
        }

        log.info( "Generating aspects." );
        log.debug( "Source: " + sourceDirectory + File.separator + dlaFile );
        log.debug( "XSLT stylesheet (in plugin jar): " + DLA_STYLESHEET );
        log.debug( "Output to: " + getAspectDirectory() );
        
        try
        {
            String aspect = new XslTransformer( stylesheet ).process(
                new FileReader( dlaSource ) );
            log.debug( "Generated aspect:");
            log.debug( aspect );
            BufferedWriter out = new BufferedWriter( new FileWriter(
                new File( getAspectDirectory(), "DesignLevelAssertions.aj" ) ) );
            out.write( aspect );
            out.close();
        }
        catch( Exception e )
        {
            throw new MojoExecutionException( e.getMessage(), e );
        }
        
    }

}
