package no.rune.mavenplugins.dla;


import java.util.Locale;
import java.util.ResourceBundle;

import org.apache.maven.doxia.sink.Sink;
import org.apache.maven.doxia.siterenderer.Renderer;
import org.apache.maven.project.MavenProject;
import org.apache.maven.reporting.AbstractMavenReport;
import org.apache.maven.reporting.MavenReportException;



/**
 * This will create a report on the project's design adherence.
 *
 * @todo Implement actual reporting. Currently, the report mojo only creates
 *       a placeholder for the DLA Report.
 *      
 * @fixme Fix the getBundle() method to read the dla-report.properties file so
 *        the report name and description can be specified here instead of being
 *        hardcoded as the are now.
 *       
 * @author Rune Flobakk
 * @phase site
 * @goal report
 */
public class DlaReportMojo extends AbstractMavenReport
{

    /**
     * @parameter expression="${project}"
     * @required
     * @readonly
     */
    protected MavenProject project;
    
    
    /**
     * <i>Maven Internal</i>: The Doxia Site Renderer.
     *
     * @component
     * @readonly
     */
    private Renderer siteRenderer;
    
    
    /**
     * @parameter expression="${project.reporting.outputDirectory}"
     * @required
     * @readonly
     */
    protected String outputDirectory;
    
    
    /**
     * Create the DLA report.
     * 
     * @see org.apache.maven.reporting.AbstractMavenReport#executeReport(java.util.Locale)
     */
    protected void executeReport( Locale locale ) throws MavenReportException
    {
        Sink sink = getSink();
        sink.head();
            sink.title();
            sink.text( this.getName( null ) );
            sink.title_();
        sink.head_();
        
        sink.body();
        sink.section1();
        
        sink.sectionTitle1();
        sink.text( this.getName( null ) );
        sink.sectionTitle1_();
        
        sink.paragraph();
        sink.text( "In the future, a nice report from the design " +
                "level assertions will be here. So don't think your " +
                "implementation is adhering to the design! ;) For now, " +
                "use the plugin as a regular build plugin, and it will automatically " +
                "test your code for design inconsistencies." );
        sink.paragraph_();
        
        sink.paragraph();
        sink.text( "For more information, see the " );
        sink.link( "usage.html" );
        sink.text( "Usage page" );
        sink.link_();
        sink.text( "." );
        sink.paragraph_();
        
        sink.section1_();
        
        sink.body_();
        sink.flush();
        sink.close();
        
        
    }


    /**
     * Output directory for the report file.
     * 
     * @see org.apache.maven.reporting.AbstractMavenReport#getOutputDirectory()
     */
    protected String getOutputDirectory()
    {
        return this.outputDirectory;
    }

    
    /**
     * @see org.apache.maven.reporting.AbstractMavenReport#getProject()
     */
    protected MavenProject getProject()
    {
        return this.project;
    }

    /**
     * @see org.apache.maven.reporting.AbstractMavenReport#getSiteRenderer()
     */
    protected Renderer getSiteRenderer()
    {
        return this.siteRenderer;
    }

    /**
     * Short report description.
     * 
     * @see org.apache.maven.reporting.MavenReport#getDescription(java.util.Locale)
     */
    public String getDescription( Locale locale )
    {
        //return this.getBundle( locale ).getString( "report.dla.description." );
        return "This report describes how the project adheres to its design.";
    }

    /**
     * The report name.
     * 
     * @see org.apache.maven.reporting.MavenReport#getName(java.util.Locale)
     */
    public String getName( Locale locale )
    {
        //return this.getBundle( locale ).getString( "report.dla.name" );
        return "DLA Report";
    }

    /**
     * The name of the output file (excl. extenstion).
     * 
     * @see org.apache.maven.reporting.MavenReport#getOutputName()
     */
    public String getOutputName()
    {
        return "dla-report";
    }
    

    public ResourceBundle getBundle(Locale locale)
    {
        
        return ResourceBundle.getBundle( "dla-report",
            locale, this.getClass().getClassLoader() );
    }


    
    
    
}
