package no.rune.mavenplugins.dla.processor;



import java.io.*;
import javax.xml.transform.*;
import javax.xml.transform.stream.*;

/**
 * This class uses an XSLT document, received on instantiation, to transform
 * documents to another format. The document formats an object will accept are
 * thus entirely dependant on the XSLT document provided when it is
 * instantiated.
 *
 * No validation is implemented at this point, but it might be in the future.
 *
 * @author Rune Flobakk
 *
 *
 */
public class XslTransformer implements Processor<Reader,String>
{

    /**
     * This handles the actual transforming of a document.
     */
    private javax.xml.transform.Transformer transformer;





    /**
     *
     * @param stylesheetResource A stream with the stylesheet to use.
     */
    public XslTransformer( InputStream stylesheetResource )
    throws TransformerConfigurationException
    {
        TransformerFactory tFactory = TransformerFactory.newInstance();

        Source stylesheet = new StreamSource( stylesheetResource );

        transformer = tFactory.newTransformer( stylesheet );
    }


    /**
     * @see no.rune.mavenplugins.dla.processor.Processor#process(Object)
     */
    public String process( Reader source )
    throws ProcessingException
    {
        Source xmlSource = new StreamSource( source );

        Writer result = new StringWriter();
        try
        {
            transformer.transform( xmlSource, new StreamResult( result ) );
        }
        catch( TransformerException e )
        {
            throw new ProcessingException( e.getMessage(), e );
        }


        return result.toString();
    }

}
