<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
   
   <xsl:output method="text"/>
   <xsl:strip-space elements="*"/>
   

   <!--
      The root element which sets up the basic aspect declaration skeleton.
      -->   
   <xsl:template match="/dla">
      package no.rune.mavenplugins.dla;   
   
      public aspect DesignLevelAssertions
      {
         <xsl:apply-templates/>
      }
   </xsl:template>

      
   
   <xsl:template match="/dla/component">
      public pointcut <xsl:value-of select="@name"/>Source():
         within( <xsl:value-of select="."/> );
      
      public pointcut <xsl:value-of select="@name"/>Target():
         call(* <xsl:value-of select="."/>.*(..) ) || call( <xsl:value-of select="."/>.new(..) );
   </xsl:template>

   
      
   <xsl:template match="rules/independent">
      <xsl:call-template name="declarationSeverity"/>
         <xsl:value-of select="."/>Target() <![CDATA[&&]]> ! <xsl:value-of select="."/>Source():
         "Violation of <xsl:value-of select="."/> component's independence!";
   </xsl:template>
   

   <xsl:template match="rules/constrainedJava">
      <xsl:call-template name="declarationSeverity"/>
         target( <xsl:value-of select="."/> ) <![CDATA[&&]]> if( ! thisJoinPoint.getDeclaringClass().isInterface() ):
         "<xsl:value-of select="."/> is declared as Constrained Java Package Space, " + 
         "and thus only interfaces are allowed to be referenced."
   </xsl:template>
   

   
   <!--
      This template will declare an error or warning depending
      on the severity attribute.
   -->
   <xsl:template name="declarationSeverity">
      <xsl:choose>
         <xsl:when test="./@severity='error'">
            declare <xsl:value-of select="./@severity"/>:
         </xsl:when>
         <xsl:otherwise>
            declare warning:
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>   
                     
</xsl:stylesheet>


