package no.rune.shellexecute;

import java.util.Map;


public interface Arguments
{

    /**
     * Add an argument. This method is a convenience method to add flag type
     * arguments (i.e. don't use post strings).
     * @param arg The argument
     */
    public void addArgument( Argument arg )
        throws MissingPostStringException;
    
    /**
     * Add an argument.
     * @param arg The argument
     * @param postString any needed following string to the argument, can
     * be <code>null</code>. Consider using {@link Arguments#addArgument(Argument)}
     * if argument is a flag type argument.
     * @throws PostStringNotAllowedException if argument is flag type and thus
     *         does not accept a post string
     * @throws MissingPostStringException if argument requires postString and
     *         postString is <code>null</code>.
     */
    public void addArgument( Argument arg, String postString )
        throws PostStringNotAllowedException, MissingPostStringException;
    


    /**
     * Add several <em>flag type</em> arguments.
     * 
     * @param args The arguments to add
     * @throws MissingPostStringException if one or more arguments requiring
     * a post string are added
     */
    public void addArguments( Argument[] args )
        throws MissingPostStringException;
    


    /**
     * Add several arguments.
     * 
     * @param args The arguments.
     * @throws PostStringNotAllowedException if the arguments map contains flag
     *         type argument(s) with post string(s).
     * @throws MissingPostStringException if the arguments map contains non-flag
     *         type argument(s) missing required post string(s). 
     */
    public void addArguments( Map<Argument, String> args )
        throws PostStringNotAllowedException, MissingPostStringException;
    
    
    /**
     * Get a stored post string for an argument.
     * @param argument The argument to look up post string for.
     * @return the post string
     * @throws PostStringNotAllowedException if argument is flag type and thus
     *         does not accept a post string
     */
    public String getPostString( Argument argument )
        throws PostStringNotAllowedException;
    
    /**
     * Gets an array containing a valid sequence of the arguments. This array
     * would for instance be suitable to send to a Java application class'
     * <code>main</code> method.
     *  
     * @return array containing every argument
     */
    public String[] getArguments();

}
