package no.rune.shellexecute;


/**
 * A simple wrapper for an arbitrary command line argument. All
 * arguments of this type is also a flag type argument, they do not
 * accept following post strings.
 * <p>
 * When added to a sorted data structure, the sorting will simply be the same
 * as the order each argument was added to the structure.
 * </p>
 * @author Rune Flobakk
 */
public class SimpleStringArgument implements Argument, Comparable<Argument>
{

    private String theArgument;
    
    public SimpleStringArgument( String argument )
    {
        theArgument = argument;
    }
    
    
    /**
     * @see no.rune.shellexecute.Argument#asString()
     */
    public String asString()
    {
        return theArgument;
    }



    /**
     * Method will always return true.
     * @see no.rune.shellexecute.Argument#isFlag()
     */
    public boolean isFlag()
    {
        return true;
    }
    

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
        return asString();
    }

    
    /**
     * @see java.lang.Object#equals(java.lang.Object)
     */
    @Override
    public boolean equals( Object anotherArgument )
    {
        return theArgument.equals( anotherArgument.toString() );
    }
    
    
    public int compareTo( Argument anotherArgument )
    {
        if( this.equals( anotherArgument ) )
            return 0;
        else 
            return +1; //makes sure that arguments are always placed after
                       //existing arguments in sorted data structures
    }


    /**
     * Convenience method to create several Argument objects from the String
     * representation (<code>toString()<code>) of several objects.
     * @param objects the objects
     * @return array of Argument objects, <code>null</code> if
     * <code>objects</code> array is empty 
     */
    public static Argument[] createArguments( Object ... objects )
    {
        if( objects == null || objects.length < 1 )
            return null;
        
        Argument[] args = new Argument[objects.length];
        
        for( int i = 0; i < args.length; i++ )
            args[i] = new SimpleStringArgument( objects[i].toString() );
        
        return args;
    }


}
