package no.rune.shellexecute;

import java.util.HashMap;
import java.util.Map;

import junit.framework.TestCase;


public class TestSpaceDelimitedArguments extends TestCase
{

    private SpaceDelimitedArguments args;
    
    public void setUp()
    {
        args = new SpaceDelimitedArguments();
    }
    
    
    public void testToString()
        throws PostStringNotAllowedException, MissingPostStringException
    {
        args.addArgument( AjcArgument.HELP );
        args.addArgument( AjcArgument.CLASSPATH, ".;junit-3.8.1.jar" );
        
        assertEquals( "-help -classpath .;junit-3.8.1.jar", args.toString() );
        
        //add an argument preceding the previous ones already added
        //to see if it is positioned correctly
        args.addArgument( AjcArgument.CROSSREFS );
        
        assertEquals( "-crossrefs -help -classpath .;junit-3.8.1.jar",
            args.toString() );
        
        
    }
    
    
    public void testAddArgumentsArray()
        throws PostStringNotAllowedException, MissingPostStringException
    {
        args.addArgument( AjcArgument.HELP );
        Argument[] theArgs = null;
        args.addArguments( theArgs );
        theArgs = new Argument[2];
        theArgs[0] = new SimpleStringArgument("test");
        theArgs[1] = new SimpleStringArgument("test2");
        args.addArguments( theArgs );
        
        assertEquals( "-help test test2", args.toString() );
    }



    public void testAddArguments()
        throws PostStringNotAllowedException, MissingPostStringException
    {
        Map<Argument, String> argMap = new HashMap<Argument, String>();
        argMap.put( AjcArgument.CLASSPATH, ".;junit-3.8.1.jar" );
        argMap.put( AjcArgument.CROSSREFS, null );
        argMap.put( AjcArgument.HELP, null );
        args.addArguments( argMap );
        
        assertEquals( "-crossrefs -help -classpath .;junit-3.8.1.jar",
            args.toString() );

        argMap = new HashMap<Argument, String>();
        argMap.put( AjcArgument.CLASSPATH, ".;jdox-1.6.1.jar" );
        argMap.put( AjcArgument.OUTXML, null );
        
        args.addArguments( argMap );
        
        
        assertEquals( "-outxml -crossrefs -help -classpath .;jdox-1.6.1.jar",
            args.toString() );

    }



    public void testGetPostString()
    {
        
        
        
        try
        {
            args.addArgument( AjcArgument.OUTXML );
            args.addArgument( AjcArgument.CLASSPATH, ".;junit-3.8.1.jar" );
            assertEquals( ".;junit-3.8.1.jar", 
                args.getPostString( AjcArgument.CLASSPATH ) );
        }
        catch( PostStringNotAllowedException e )
        {
            fail( "Exception handling does not work properly.\n" +
                e.getMessage() );
        }
        catch( MissingPostStringException e )
        {
            fail( "Exception handling does not work properly.\n" +
                e.getMessage() );
        }
        
        
        
        try
        {
            assertEquals( null, 
                args.getPostString( AjcArgument.HELP ) );
        }
        catch( PostStringNotAllowedException e )
        {
            //expected, so return from the test method.
            return;
        }
        fail( "SpaceDelimitedArguments should have thrown " +
                "PostStringNotAllowedException" );
        
        
    }



    public void testGetArguments()
        throws PostStringNotAllowedException, MissingPostStringException
    {
        args.addArgument( AjcArgument.CLASSPATH, ".;junit-3.8.1.jar" );
        args.addArgument( AjcArgument.HELP );
        args.addArgument( AjcArgument.CROSSREFS );
        
        assertEquals( "-crossrefs", args.getArguments()[0] );
        assertEquals( "-help", args.getArguments()[1] );
        assertEquals( "-classpath", args.getArguments()[2] );
        assertEquals( ".;junit-3.8.1.jar", args.getArguments()[3] );
    }

}
